%% Obtain shocks to treas/libor basis
% Copy data and convert everything to percents
moments = US;
moments.mean_treas_basis = moments.mean_treas_basis/10000;
moments.median_treas_basis = moments.median_treas_basis/10000;
moments.mean_libor_basis = moments.mean_libor_basis/10000;
moments.median_libor_basis = moments.median_libor_basis/10000;
moments.ds3 = moments.mean_ds3*100;
moments.drf = moments.mean_drf*100;

% Calculate forward change in bases
moments.mean_treas_basis_f = [moments.mean_treas_basis(2:end); NaN];
moments.mean_libor_basis_f = [moments.mean_libor_basis(2:end); NaN];
moments.dtreas_basis = moments.mean_treas_basis_f - moments.mean_treas_basis;
moments.dlibor_basis = moments.mean_libor_basis_f - moments.mean_libor_basis;

% Lagged value of bases
moments.mean_treas_basis_l = [NaN; moments.mean_treas_basis(1:end-1)];
moments.mean_libor_basis_l = [NaN; moments.mean_libor_basis(1:end-1)];

% Estimate regression
model_treas = fitlm([moments.mean_treas_basis moments.mean_treas_basis_l moments.mean_drf],moments.dtreas_basis);
model_libor = fitlm([moments.mean_libor_basis moments.mean_libor_basis_l moments.mean_drf],moments.dlibor_basis);

% Keep residuals as shocks
moments.shock_t3 = model_treas.Residuals.Raw;
moments.shock_l3 = model_libor.Residuals.Raw;

% Lags of shock
moments.shock_t3_l = [NaN; moments.shock_t3(1:end-1)];
moments.shock_l3_l = [NaN; moments.shock_l3(1:end-1)];

%% Regressions by subsample
sample = {'allsample','pre2008','post2008'};
for j = 1:length(sample)

    if strcmp(sample(j),'allsample')
        subsample = moments;
    elseif strcmp(sample(j),'pre2008')
        subsample = moments(moments.date <= datenum(2007,12,31),:);
    elseif strcmp(sample(j),'post2008')
        subsample = moments(moments.date > datenum(2007,12,31),:);         
    end

    FX_model{j,1} = fitlm(subsample.shock_t3,subsample.mean_ds3);
    FX_model{j,2} = fitlm(subsample.shock_l3,subsample.mean_ds3);
    FX_model{j,3} = fitlm([subsample.shock_t3 subsample.shock_t3_l],subsample.mean_ds3);

end
    
%% Send to Latex
% Document and table settings
latex = {'\documentclass[11pt,English]{article}'};
latex(end+1,1) = {'\usepackage[margin=1in]{geometry}'};
latex(end+1,1) = {'\begin{document}'};
latex(end+1,1) = {'\begin{table}[tbh]'};
latex(end+1,1) = {'\centering'};
latex(end+1,1) = strcat({'\caption{Average Treasury Basis and Changes in the USD Spot Exchange Rate}'});
latex(end+1,1) = {'\label{tab:changes1}'};
latex(end+1,1) = {'\begin{tabular}{llll|ll|ll}'};
latex(end+1,1) = {'&\multicolumn{3}{c}{1988Q1-2017Q2}&\multicolumn{2}{c}{1988Q1-2007Q4}&\multicolumn{2}{c}{2008Q1-2017Q2}\\'};
latex(end+1,1) = {'\hline'};
latex(end+1,1) = {'&(1)&(2)&(3)&(4)&(5)&(6)&(7)\\'};
latex(end+1,1) = {'\hline'};
latex(end+1,1) = {'&&&&&&&\\'};

% Obtain data from FX_model
C = {};
col = 0;
for j = 1:3
    for k = 1:3

        if k == 3 & j > 1 
            continue
        end
        
        row = 1;
        col = col + 1;
        if k == 2
            row = 5;
        end

        if FX_model{j,k}.Coefficients{2,4} <= .01
            stars = '***';
        elseif FX_model{j,k}.Coefficients{2,4} <= .05
            stars = '**';
        elseif FX_model{j,k}.Coefficients{2,4} <= .1
            stars = '*';
        else
            stars = '';
        end
        C{row,col} = strcat(num2str(round(FX_model{j,k}.Coefficients{2,1},1)),stars);
        C{row+1,col} = strcat('(',num2str(round(FX_model{j,k}.Coefficients{2,2},1)),')');

        if k == 3
            if FX_model{j,k}.Coefficients{3,4} <= .01
                stars = '***';
            elseif FX_model{j,k}.Coefficients{3,4} <= .05
                stars = '**';
            elseif FX_model{j,k}.Coefficients{3,4} <= .1
                stars = '*';
            else
                stars = '';
            end
            C{row+2,col} = strcat(num2str(round(FX_model{j,k}.Coefficients{3,1},1)),stars);
            C{row+3,col} =  strcat('(',num2str(round(FX_model{j,k}.Coefficients{2,2},1)),')');
        end

        if col == 1
            C{8,col} = strcat(num2str(round(FX_model{j,k}.Rsquared.Ordinary*100,1)),'\%');
        else
            C{8,col} = num2str(round(FX_model{j,k}.Rsquared.Ordinary*100,1));
        end
        C{9,col} = num2str(round(FX_model{j,k}.NumObservations,1));

    end
end

% Row headings
R{1,1} = '$\Delta\overline{x}^{Treas}$';
R{3,1} = 'Lag $\Delta\overline{x}^{Treas}$';
R{5,1} = '$\Delta\overline{x}^{LIBOR}$';
R{8,1} = '$R^2$';
R{9,1} = 'N';
for j = 1:size(C,1)
    rowStr = R{j,1};
    for k = 1:size(C,2)
        rowStr = strcat(rowStr,'&',C(j,k));
    end
    rowStr = strcat(rowStr,'\\');
    latex(end+1,1) = rowStr;
end

% End table and document
latex(end+1,1) = {'\hline\hline'};
latex(end+1,1) = {'\end{tabular}'};
latex(end+1,1) = {'\end{table}'};
latex(end+1,1) = {'\end{document}'};

% Print to file
fileID = fopen('results/Table1_USD.tex','w');
formatSpec = '%s\n';
[nrows,~] = size(latex);
for row = 1:nrows
    fprintf(fileID,formatSpec,latex{row,:});
end
fclose(fileID);
latex
